# Naturalisation
Small python script to parse a pdf from https://www.legifrance.gouv.fr in order to search for all persons that obtained the French nationality within the pdf file.
Keeps track of number of persons, name, origin, and department of a specific series (54 series by year).
